#!/usr/bin/env python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

# @ <SNIPPET>
from openeye import oechem

qfile = oechem.oemolistream("query.mol")
tfile = oechem.oemolistream("targets.sdf")

# read MDL query and initialize the substructure search
qmol = oechem.OEQMol()
oechem.OEReadMDLQueryFile(qfile, qmol)
ss = oechem.OESubSearch(qmol)

# loop over target structures
tindex = 1
for tmol in tfile.GetOEGraphMols():
    oechem.OEAddExplicitHydrogens(tmol)
    oechem.OEPrepareSearch(tmol, ss)
    for mi in ss.Match(tmol, True):
        print("hit target = %d" % tindex, end=" ")
        for ai in mi.GetTargetAtoms():
            print("%d%s" % (ai.GetIdx(), oechem.OEGetAtomicSymbol(ai.GetAtomicNum())), end=" ")
        print()
    tindex += 1
# @ </SNIPPET>
